powerdns
    * ``auth_token`` Specify token for authentication

    * ``pdns_server`` Uri for powerdns server

    * ``pdns_server_id`` Server id to interact with

    * ``pdns_disable_notify`` Disable slave notifications from master
